@@ -31,7 +31,6 @@ from darwin.dataset.utils import (
     exhaust_generator,
     get_annotations,
     get_classes,
-    is_relative_to,
     is_unix_like_os,
     make_class_lists,
     sanitize_filename,
@@ -41,15 +40,16 @@ from darwin.exceptions import NotFound, UnsupportedExportFormat
 from darwin.exporter.formats.darwin import build_image_annotation
 from darwin.item import DatasetItem
 from darwin.item_sorter import ItemSorter
-from darwin.utils import find_files, parse_darwin_json, split_video_annotation, urljoin
-from requests.models import Response
+from darwin.utils import parse_darwin_json, split_video_annotation, urljoin
 from rich.console import Console
 
 if TYPE_CHECKING:
     from darwin.client import Client
 
+from abc import ABC, abstractmethod
 
-class RemoteDataset:
+
+class RemoteDataset(ABC):
     """
     Manages the remote and local versions of a dataset hosted on Darwin.
     It allows several dataset management operations such as syncing between
@@ -104,6 +104,7 @@ class RemoteDataset:
         dataset_id: int,
         item_count: int = 0,
         progress: float = 0,
+        version: int = 1,
     ):
         self.team = team
         self.name = name
@@ -114,7 +115,9 @@ class RemoteDataset:
         self.client = client
         self.annotation_types: Optional[List[Dict[str, Any]]] = None
         self.console: Console = Console()
+        self.version = version
 
+    @abstractmethod
     def push(
         self,
         files_to_upload: Optional[List[Union[PathLike, LocalFile]]],
@@ -129,81 +132,7 @@ class RemoteDataset:
         progress_callback: Optional[ProgressCallback] = None,
         file_upload_callback: Optional[FileUploadCallback] = None,
     ) -> UploadHandler:
-        """
-        Uploads a local dataset (images ONLY) in the datasets directory.
-
-        Parameters
-        ----------
-        files_to_upload : Optional[List[Union[PathLike, LocalFile]]]
-            List of files to upload. Those can be folders.
-        blocking : bool, default: True
-            If False, the dataset is not uploaded and a generator function is returned instead.
-        multi_threaded : bool, default: True
-            Uses multiprocessing to upload the dataset in parallel.
-            If blocking is False this has no effect.
-        fps : int, default: 0
-            When the uploading file is a video, specify its framerate.
-        as_frames: bool, default: False
-            When the uploading file is a video, specify whether it's going to be uploaded as a list of frames.
-        files_to_exclude : Optional[PathLike]], default: None
-            Optional list of files to exclude from the file scan. Those can be folders.
-        path: Optional[str], default: None
-            Optional path to store the files in.
-        preserve_folders : bool, default: False
-            Specify whether or not to preserve folder paths when uploading
-        progress_callback: Optional[ProgressCallback], default: None
-            Optional callback, called every time the progress of an uploading files is reported.
-        file_upload_callback: Optional[FileUploadCallback], default: None
-            Optional callback, called every time a file chunk is uploaded.
-
-        Returns
-        -------
-        handler : UploadHandler
-           Class for handling uploads, progress and error messages.
-
-        Raises
-        ------
-        ValueError
-            - If ``files_to_upload`` is ``None``.
-            - If a path is specified when uploading a LocalFile object.
-            - If there are no files to upload (because path is wrong or the exclude filter excludes everything).
-        """
-
-        if files_to_exclude is None:
-            files_to_exclude = []
-
-        if files_to_upload is None:
-            raise ValueError("No files or directory specified.")
-
-        uploading_files = [item for item in files_to_upload if isinstance(item, LocalFile)]
-        search_files = [item for item in files_to_upload if not isinstance(item, LocalFile)]
-
-        generic_parameters_specified = path is not None or fps != 0 or as_frames is not False
-        if uploading_files and generic_parameters_specified:
-            raise ValueError("Cannot specify a path when uploading a LocalFile object.")
-
-        for found_file in find_files(search_files, files_to_exclude=files_to_exclude):
-            local_path = path
-            if preserve_folders:
-                source_files = [source_file for source_file in search_files if is_relative_to(found_file, source_file)]
-                if source_files:
-                    local_path = str(found_file.relative_to(source_files[0]).parent)
-            uploading_files.append(LocalFile(found_file, fps=fps, as_frames=as_frames, path=local_path))
-
-        if not uploading_files:
-            raise ValueError("No files to upload, check your path, exclusion filters and resume flag")
-
-        handler = UploadHandler(self, uploading_files)
-        if blocking:
-            handler.upload(
-                multi_threaded=multi_threaded,
-                progress_callback=progress_callback,
-                file_upload_callback=file_upload_callback,
-            )
-        else:
-            handler.prepare_upload()
-
-        return handler
+        pass
 
     def split_video_annotations(self, release_name: str = "latest") -> None:
         """
@@ -383,6 +312,7 @@ class RemoteDataset:
         """Archives (soft-deletion) this ``RemoteDataset``."""
         self.client.archive_remote_dataset(self.dataset_id, self.team)
 
+    @abstractmethod
     def fetch_remote_files(
         self, filters: Optional[Dict[str, Union[str, List[str]]]] = None, sort: Optional[Union[str, ItemSorter]] = None
     ) -> Iterator[DatasetItem]:
@@ -402,95 +332,61 @@ class RemoteDataset:
         Iterator[DatasetItem]
             An iterator of ``DatasetItem``.
         """
-        post_filters: Dict[str, Union[str, List[str]]] = {}
-        post_sort: Dict[str, str] = {}
-
-        if filters:
-            for list_type in ["filenames", "statuses"]:
-                if list_type in filters:
-                    if type(filters[list_type]) is list:
-                        post_filters[list_type] = filters[list_type]
-                    else:
-                        post_filters[list_type] = str(filters[list_type])
-            if "path" in filters:
-                post_filters["path"] = str(filters["path"])
-            if "types" in filters:
-                post_filters["types"] = str(filters["types"])
-
-            if sort:
-                item_sorter = ItemSorter.parse(sort)
-                post_sort[item_sorter.field] = item_sorter.direction.value
-        cursor = {"page[size]": 500}
-        while True:
-            payload = {"filter": post_filters, "sort": post_sort}
-            response = self.client.fetch_remote_files(self.dataset_id, cursor, payload, self.team)
-
-            yield from [DatasetItem.parse(item) for item in response["items"]]
-
-            if response["metadata"]["next"]:
-                cursor["page[from]"] = response["metadata"]["next"]
-            else:
-                return
 
+    @abstractmethod
     def archive(self, items: Iterator[DatasetItem]) -> None:
         """
-        Archives (soft-deletion) the given ``DatasetItem``s belonging to this ``RemoteDataset``.
+        Archives (soft-deletion) the given ``DatasetItem``\\s belonging to this ``RemoteDataset``.
 
         Parameters
         ----------
         items : Iterator[DatasetItem]
-            The ``DatasetItem``s to be archived.
+            The ``DatasetItem``\\s to be archived.
         """
-        payload: Dict[str, Any] = {"filter": {"dataset_item_ids": [item.id for item in items]}}
-        self.client.archive_item(self.slug, self.team, payload)
 
+    @abstractmethod
     def restore_archived(self, items: Iterator[DatasetItem]) -> None:
         """
-        Restores the archived ``DatasetItem``s that belong to this ``RemoteDataset``.
+        Restores the archived ``DatasetItem``\\s that belong to this ``RemoteDataset``.
 
         Parameters
         ----------
         items : Iterator[DatasetItem]
-            The ``DatasetItem``s to be restored.
+            The ``DatasetItem``\\s to be restored.
         """
-        payload: Dict[str, Any] = {"filter": {"dataset_item_ids": [item.id for item in items]}}
-        self.client.restore_archived_item(self.slug, self.team, payload)
 
+    @abstractmethod
     def move_to_new(self, items: Iterator[DatasetItem]) -> None:
         """
-        Changes the given ``DatasetItem``s status to ``new``.
+        Changes the given ``DatasetItem``\\s status to ``new``.
 
         Parameters
         ----------
         items : Iterator[DatasetItem]
-            The ``DatasetItem``s whose status will change.
+            The ``DatasetItem``\\s whose status will change.
         """
-        payload: Dict[str, Any] = {"filter": {"dataset_item_ids": [item.id for item in items]}}
-        self.client.move_item_to_new(self.slug, self.team, payload)
 
+    @abstractmethod
     def reset(self, items: Iterator[DatasetItem]) -> None:
         """
-        Resets the given ``DatasetItem``s.
+        Resets the given ``DatasetItem``\\s.
 
         Parameters
         ----------
         items : Iterator[DatasetItem]
-            The ``DatasetItem``s to be resetted.
+            The ``DatasetItem``\\s to be resetted.
         """
-        payload: Dict[str, Any] = {"filter": {"dataset_item_ids": [item.id for item in items]}}
-        self.client.reset_item(self.slug, self.team, payload)
 
+    @abstractmethod
     def delete_items(self, items: Iterator[DatasetItem]) -> None:
         """
-        Deletes the given ``DatasetItem``s.
+        Deletes the given ``DatasetItem``\\s.
 
         Parameters
         ----------
         items : Iterator[DatasetItem]
-            The ``DatasetItem``s to be deleted.
+            The ``DatasetItem``\\s to be deleted.
         """
-        payload: Dict[str, Any] = {"filter": {"dataset_item_ids": [item.id for item in items]}}
-        self.client.delete_item(self.slug, self.team, payload)
 
     def fetch_annotation_type_id_for_name(self, name: str) -> Optional[int]:
         """
@@ -643,6 +539,7 @@ class RemoteDataset:
         """
         return self.client.fetch_remote_attributes(self.dataset_id)
 
+    @abstractmethod
     def export(
         self,
         name: str,
@@ -666,17 +563,8 @@ class RemoteDataset:
             If set, include annotator and reviewer metadata for each annotation.
 
         """
-        if annotation_class_ids is None:
-            annotation_class_ids = []
-
-        payload = {
-            "annotation_class_ids": annotation_class_ids,
-            "name": name,
-            "include_export_token": include_url_token,
-            "include_authorship": include_authorship,
-        }
-        self.client.create_export(self.dataset_id, payload, self.team)
 
+    @abstractmethod
     def get_report(self, granularity: str = "day") -> str:
         """
         Returns a String representation of a CSV report for this ``RemoteDataset``.
@@ -691,9 +579,8 @@ class RemoteDataset:
         str
             A CSV report.
         """
-        response: Response = self.client.get_report(self.dataset_id, granularity, self.team)
-        return response.text
 
+    @abstractmethod
     def get_releases(self) -> List["Release"]:
         """
         Get a sorted list of releases with the most recent first.
@@ -701,15 +588,8 @@ class RemoteDataset:
         Returns
         -------
         List["Release"]
-            Returns a sorted list of available ``Release``s with the most recent first.
+            Returns a sorted list of available ``Release``\\s with the most recent first.
         """
-        try:
-            releases_json: List[Dict[str, Any]] = self.client.get_exports(self.dataset_id, self.team)
-        except NotFound:
-            return []
-
-        releases = [Release.parse_json(self.slug, self.team, payload) for payload in releases_json]
-        return sorted(filter(lambda x: x.available, releases), key=lambda x: x.version, reverse=True)
 
     def get_release(self, name: str = "latest") -> "Release":
         """
@@ -862,6 +742,7 @@ class RemoteDataset:
         ):
             yield annotation
 
+    @abstractmethod
     def workview_url_for_item(self, item: DatasetItem) -> str:
         """
         Returns the darwin URL for the given ``DatasetItem``.
@@ -876,7 +757,12 @@ class RemoteDataset:
         str
             The url.
         """
-        return urljoin(self.client.base_url, f"/workview?dataset={self.dataset_id}&image={item.seq}")
+
+    @abstractmethod
+    def post_comment(self, item_id: str, text: str, x: int, y: int, w: int, h: int) -> None:
+        """
+        Adds a comment to an items in this dataset
+        """
 
     @property
     def remote_path(self) -> Path:
