@@ -22,6 +22,7 @@ import deprecation
 import numpy as np
 from rich.progress import ProgressType, track
 from upolygon import draw_polygon
+from requests import Response
 
 import darwin.datatypes as dt
 from darwin.config import Config
@@ -598,7 +599,7 @@ def split_video_annotation(annotation: dt.AnnotationFile) -> List[dt.AnnotationF
     Returns
     -------
     List[dt.AnnotationFile]
-        A list with the split video ``AnnotationFile``s.
+        A list with the split video ``AnnotationFile``\\s.
 
     Raises
     ------
@@ -674,6 +675,7 @@ def convert_polygons_to_sequences(
         Maximum width for a polygon coordinate.
     rounding : bool, default: True
         Whether or not to round values when creating sequences.
+
     Returns
     -------
     sequences: List[ndarray[float]]
@@ -892,3 +894,29 @@ def is_unix_like_os() -> bool:
         True for Unix-based systems, False otherwise.
     """
     return platform.system() != "Windows"
+
+def has_json_content_type(response: Response) -> bool:
+    """
+    Returns ``True`` if response has application/json content type or ``False``
+    otherwise.
+
+    Returns
+    --------
+    bool
+        True for application/json content type, False otherwise.
+    """
+    return "application/json" in response.headers.get("content-type", "")
+
+def get_response_content(response: Response) -> Any:
+    """
+    Returns json content if response has application/json content-type, otherwise returns text.
+
+    Returns
+    --------
+    Any
+        Json or text content.
+    """
+    if has_json_content_type(response):
+        return response.json()
+    else:
+        return response.text
